==> audio-convert-mod-3.41.tar.gz: audio-convert-mod-3.41/bin-usr-instl.sh <==
#!/bin/bash
#     Copyright (C) 2005, 2006 Stewart Adam
#    This file is part of audio-convert-mod.

#    FWaudio-convert-mod is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.

#    FWaudio-convert-mod is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with FWaudio-convert-mod; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

# The system installer to be copied into /usr/bin for later use
# If you are looking for the user install script it's called 'userinstall.sh'

ROOT_UID=0   # Root has $UID 0.
if [ "$UID" -eq "$ROOT_UID" ];then
	echo "Please do not run this script as root."
else
	mkdir -p ~/.gnome2/nautilus-scripts/audio-covert-mod
	cp /usr/bin/audio-convert-mod ~/.gnome2/nautilus-scripts/audio-covert-mod/"Convert Files (v3.41)"
	chmod +x ~/.gnome2/nautilus-scripts/audio-covert-mod/"Convert Files (v3.41)"
	cp /usr/bin/remove-converted-endings ~/.gnome2/nautilus-scripts/audio-covert-mod/"Remove .converted from files or folder contents"
	chmod +x ~/.gnome2/nautilus-scripts/audio-covert-mod/"Remove .converted from files or folder contents"
	echo "User install complete."
fi

==> audio-convert-mod-3.42.tar.gz: audio-convert-mod-3.42/bin-usr-instl.sh <==
#!/bin/bash
#     Copyright (C) 2005, 2006 Stewart Adam
#    This file is part of audio-convert-mod.

#    audio-convert-mod is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.

#    FWaudio-convert-mod is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with FWaudio-convert-mod; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

# The system installer to be copied into /usr/bin for later use
# If you are looking for the user install script it's called 'userinstall.sh'

ROOT_UID=0   # Root has $UID 0.
if [ "$UID" -eq "$ROOT_UID" ];then
	echo "Please do not run this script as root."
else
	mkdir -p ~/.gnome2/nautilus-scripts/audio-covert-mod
	cp /usr/local/bin/audio-convert-mod ~/.gnome2/nautilus-scripts/audio-covert-mod/"Convert Files (v3.42)"
	chmod +x ~/.gnome2/nautilus-scripts/audio-covert-mod/"Convert Files (v3.42)"
	cp /usr/local/bin/remove-converted-endings ~/.gnome2/nautilus-scripts/audio-covert-mod/"Remove .converted from files or folder contents"
	chmod +x ~/.gnome2/nautilus-scripts/audio-covert-mod/"Remove .converted from files or folder contents"
	echo "User install complete."
fi
